@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 #   This file is part of nexdatas - Tango Server for NeXus data writer
 #
 #    Copyright (C) 2012-2018 DESY, Jan Kotanski <jkotan@mail.desy.de>
@@ -311,13 +310,18 @@ class BeamtimeLoader(object):
         "description": "title",   # ?? should be from dataset
         "createdAt": "generated",  # ?? should be automatic
         "updatedAt": "generated",  # ?? should be automatic
-        "proposalId": "proposalId",
+        # "proposalId": "proposalId",
+        "proposalId": "beamtimeId",
     }
 
     strcre = {
         "creationLocation": "/DESY/{facility}/{beamline}",
         "type": "raw",
         "isPublished": False,
+        "ownerGroup": "{beamtimeId}-part",
+        "accessGroups": ["{beamtimeId}-clbt",
+                         "{beamtimeId}-dmgt",
+                         "{beamline}dmgt"]
     }
 
     cre = {
@@ -378,6 +382,12 @@ class BeamtimeLoader(object):
         :type options: :class:`argparse.Namespace`
         """
         self.__pid = options.pid
+        self.__pap = options.pap
+        self.__relpath = options.relpath
+        self.__ownergroup = options.ownergroup
+        self.__accessgroups = None
+        if options.accessgroups is not None:
+            self.__accessgroups = options.accessgroups.split(",")
         dct = {}
         if options.beamtimemeta:
             with open(options.beamtimemeta, "r") as fl:
@@ -412,6 +422,8 @@ class BeamtimeLoader(object):
         :rtype: :obj:`dict` <:obj:`str`, `any`>
         """
 
+        if self.__pap:
+            self.btmdmap["proposalId"] = "proposalId"
         if self.__btmeta:
             for sc, ds in self.btmdmap.items():
                 sds = ds.split(".")
@@ -425,10 +437,20 @@ class BeamtimeLoader(object):
                 else:
                     self.__metadata[sc] = md
             for sc, vl in self.strcre.items():
-                if hasattr(vl, "format"):
-                    self.__metadata[sc] = vl.format(**self.__btmeta)
+                if isinstance(vl, list):
+                    self.__metadata[sc] = [
+                        (vv.format(**self.__btmeta)
+                         if hasattr(vv, "format") else vv)
+                        for vv in vl
+                    ]
                 else:
-                    self.__metadata[sc] = vl
+                    if hasattr(vl, "format"):
+                        self.__metadata[sc] = vl.format(**self.__btmeta)
+                    else:
+                        self.__metadata[sc] = vl
+        if self.__relpath and "sourceFolder" in self.__metadata:
+            self.__metadata["sourceFolder"] = \
+                os.path.join(self.__metadata["sourceFolder"], self.__relpath)
         if self.__scmeta or self.__btmeta:
             self.__metadata["scientificMetadata"] = {}
         if self.__scmeta:
@@ -437,8 +459,16 @@ class BeamtimeLoader(object):
            "beamtimeId" not in self.__metadata["scientificMetadata"]:
             self.__metadata["scientificMetadata"]["beamtimeId"] = \
                 self.__btmeta["beamtimeId"]
+        if self.__btmeta and \
+           "DOOR_proposalId" not in self.__metadata["scientificMetadata"]:
+            self.__metadata["scientificMetadata"]["DOOR_proposalId"] = \
+                self.__btmeta["proposalId"]
         if self.__pid:
             self.__metadata["pid"] = self.__pid
+        if self.__ownergroup:
+            self.__metadata["ownerGroup"] = self.__ownergroup
+        if self.__accessgroups is not None:
+            self.__metadata["accessGroups"] = self.__accessgroups
         # print(self.__metadata)
         return self.__metadata
 
@@ -573,6 +603,12 @@ class BeamtimeLoader(object):
                     metadata["pid"] = "%s/%s" % \
                         (beamtimeid, scanid)
 
+        if "datasetName" not in metadata and "pid" in metadata:
+            spid = metadata["pid"].split("/")
+            if len(spid) > 1:
+                metadata["datasetName"] = spid[1]
+            else:
+                metadata["datasetName"] = metadata["pid"]
         return metadata
 
 
@@ -614,11 +650,20 @@ class Metadata(Runner):
             " which value should be shown"
             " (separated by commas without spaces)",
             dest="values", default="")
+        self._parser.add_argument(
+            "-w", "--owner-group",
+            default="", dest="ownergroup",
+            help="owner group name. Default is {beamtimeid}-part")
+        self._parser.add_argument(
+            "-c", "--access-groups",
+            default=None, dest="accessgroups",
+            help="access group names separated by commas. "
+            "Default is {beamtimeid}-clbt,{beamtimeId}-dmgt,{beamline}dmgt")
         self._parser.add_argument(
             "-g", "--group-postfix",
             help="postfix to be added to NeXus group name. "
-            "The  default: 'Parameters'",
-            dest="group_postfix", default="Parameters")
+            "The  default: ''",
+            dest="group_postfix", default="")
         self._parser.add_argument(
             "-t", "--entry-classes",
             help="names of entry NX_class to be shown"
@@ -634,7 +679,7 @@ class Metadata(Runner):
             "The  default: ''",
             dest="entrynames", default="")
         self._parser.add_argument(
-            "-r", "--raw-metadata", action="store_true",
+            "-m", "--raw-metadata", action="store_true",
             default=False, dest="rawscientific",
             help="do not store NXentry as scientificMetadata")
         self._parser.add_argument(
@@ -651,6 +696,10 @@ class Metadata(Runner):
             "-d", "--pid-without-filename", action="store_true",
             default=False, dest="pfname",
             help=("generate pid without file name"))
+        self._parser.add_argument(
+            "--proposal-as-proposal", action="store_true",
+            default=False, dest="pap",
+            help=("Store the DESY proposal as the SciCat proposal"))
         self._parser.add_argument(
             "--h5py", action="store_true",
             default=False, dest="h5py",
@@ -671,6 +720,9 @@ class Metadata(Runner):
         self._parser.add_argument(
             "-o", "--output", dest="output",
             help=("output scicat metadata file"))
+        self._parser.add_argument(
+            "-r", "--relative-path", dest="relpath",
+            help=("relative path to the scan files"))
         self._parser.add_argument(
             'args', metavar='nexus_file', type=str, nargs="*",
             help='new nexus file name')
@@ -871,8 +923,14 @@ class OrigDatablock(Runner):
             "-p", "--pid", dest="pid",
             help=("dataset pid"))
         self._parser.add_argument(
-            "-o", "--output", dest="output",
-            help=("output scicat metadata file"))
+            "-w", "--owner-group",
+            default="", dest="ownergroup",
+            help="owner group name. Default is {beamtimeid}-part")
+        self._parser.add_argument(
+            "-c", "--access-groups",
+            default=None, dest="accessgroups",
+            help="access group names separated by commas. "
+            "Default is {beamtimeid}-clbt,{beamtimeId}-dmgt")
         self._parser.add_argument(
             "-s", "--skip",
             help="filters for files to be skipped (separated by commas "
@@ -889,6 +947,12 @@ class OrigDatablock(Runner):
         self._parser.add_argument(
             'args', metavar='scan_name', type=str, nargs=1,
             help='scan name')
+        self._parser.add_argument(
+            "-o", "--output", dest="output",
+            help=("output scicat metadata file"))
+        self._parser.add_argument(
+            "-r", "--relative-path", dest="relpath",
+            help=("relative path to scan files"))
 
     def run(self, options):
         """ the main program function
@@ -925,7 +989,7 @@ class OrigDatablock(Runner):
                     break
         return found
 
-    def datafiles(self, scanpath, scdir, scfiles, filters=None):
+    def datafiles(self, scanpath, scdir, scfiles, relpath, filters=None):
         dtfiles = []
         totsize = 0
         pdc = {'7': 'rwx', '6': 'rw-', '5': 'r-x', '4': 'r--',
@@ -947,6 +1011,8 @@ class OrigDatablock(Runner):
             path = os.path.join(scdir, fl)
             if path.startswith("./"):
                 path = path[2:]
+            if relpath:
+                path = os.path.join(relpath, path)
             rec["path"] = path
             rec["size"] = status.st_size
             rec["time"] = self.isotime(status.st_ctime)
@@ -990,14 +1056,16 @@ class OrigDatablock(Runner):
             scanfiles = [f for f in filenames if f.startswith(scanname)]
             scandirs = [f for f in dirnames if f.startswith(scanname)]
             break
-        flist, tsize = self.datafiles(scandir, "", scanfiles, skip)
+        flist, tsize = self.datafiles(scandir, "", scanfiles,
+                                      options.relpath, skip)
         dtfiles.extend(flist)
         totsize += tsize
 
         for fl in add:
             if os.path.isfile(fl):
                 ascandir, ascanname = os.path.split(os.path.abspath(fl))
-                flist, tsize = self.datafiles(scandir, ascandir, [ascanname])
+                flist, tsize = self.datafiles(
+                    scandir, ascandir, [ascanname], options.relpath)
                 dtfiles.extend(flist)
                 totsize += tsize
 
@@ -1005,13 +1073,30 @@ class OrigDatablock(Runner):
             for (dirpath, dirnames, filenames) in os.walk(
                     os.path.join(scandir, scdir)):
                 flist, tsize = self.datafiles(
-                    scandir, dirpath, filenames, skip)
+                    scandir, dirpath, filenames, options.relpath, skip)
                 dtfiles.extend(flist)
                 totsize += tsize
         result["dataFileList"] = dtfiles
         result["size"] = totsize
+        if options.ownergroup:
+            result["ownerGroup"] = options.ownergroup
+        if options.accessgroups is not None:
+            accessgroups = options.accessgroups.split(",")
+            result["accessGroups"] = accessgroups
         if options.pid:
             result["datasetId"] = options.pid
+        if "datasetId" in result \
+           and result["datasetId"] and \
+           len(result["datasetId"].split("/")) > 1:
+            if "ownerGroup" not in result:
+                result["ownerGroup"] = "%s-part" % (
+                    result["datasetId"].split("/")[1])
+            if "accessGroups" not in result:
+                result["accessGroups"] = [
+                    "%s-clbt" % (
+                        result["datasetId"].split("/")[1]),
+                    "%s-dmgt" % (
+                        result["datasetId"].split("/")[1])]
         return json.dumps(
                 result, sort_keys=True, indent=4,
                 cls=numpyEncoder)
