@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 #   This file is part of nexdatas - Tango Server for NeXus data writer
 #
 #    Copyright (C) 2012-2018 DESY, Jan Kotanski <jkotan@mail.desy.de>
@@ -149,7 +148,7 @@ class NXSFileParser(object):
         #: (:obj:`str`) metadata JSON dictionary
         self.metadata = ""
         #: (:obj:`str`) group postfix
-        self.group_postfix = "Parameters"
+        self.group_postfix = ""
         #: (:obj:`bool`) store NXentries as scientificMetadata
         self.scientific = False
         #: (:obj:`dict` <:obj:`str`, `any`>)  metadata dictionary
