@@ -116,6 +116,68 @@ standardComponentVariables = {
             'doc': "throttle enable status for maia (datasource)"
         },
     },
+    'secop': {
+        'host': {
+            'default': None,
+            'doc': "secop host name (string)"
+        },
+        'port': {
+            'default': '5000',
+            'doc': "secop port name (string)"
+        },
+        'message': {
+            'default': None,
+            'doc': "secop command MANDATORY (string)"
+        },
+        'timeout': {
+            'default': '0.0001',
+            'doc': "secop timeout (string)"
+        },
+    },
+    'groupsecop': {
+        'host': {
+            'default': None,
+            'doc': "secop host name (string)"
+        },
+        'port': {
+            'default': '5000',
+            'doc': "secop port name (string)"
+        },
+        'message': {
+            'default': None,
+            'doc': "secop command MANDATORY (string)"
+        },
+        'timeout': {
+            'default': '0.0001',
+            'doc': "secop timeout (string)"
+        },
+        'group': {
+            'default': None,
+            'doc': "secop group name (string)"
+        },
+        'access': {
+            'default': None,
+            'doc': "secop access list (string)"
+        },
+    },
+    'singlesecop': {
+        'host': {
+            'default': None,
+            'doc': "secop host name (string)"
+        },
+        'port': {
+            'default': '5000',
+            'doc': "secop port name (string)"
+        },
+        'message': {
+            'default': None,
+            'doc': "secop command MANDATORY (string)"
+        },
+        'timeout': {
+            'default': '0.0001',
+            'doc': "secop timeout (string)"
+        },
+    },
     'pointdet': {
         'data': {
             'default': None,
@@ -757,6 +819,8 @@ standardComponentVariables = {
             "If it is  not set it is not created (string)"
         },
     },
+    'starttime': {
+    },
     'beamtimeid': {
         'shortname': {
             'default': "P09",
@@ -1331,6 +1395,21 @@ standardComponentTemplateFiles = {
         'qbpm_foil.ds.xml',
         'qbpm.xml',
     ],
+    'secop': [
+        'secop.ds.xml',
+        'secop_time.ds.xml',
+        'client_start_time.ds.xml',
+    ],
+    'singlesecop': [
+        'singlesecop.ds.xml',
+        'singlesecop_time.ds.xml',
+        'client_start_time.ds.xml',
+    ],
+    'groupsecop': [
+        'groupsecop.ds.xml',
+        'groupsecop_time.ds.xml',
+        'client_start_time.ds.xml',
+    ],
     'slit': ['slit.xml'],
     'source': ['source.xml'],
     'undulator': ['undulator.xml'],
@@ -1339,6 +1418,12 @@ standardComponentTemplateFiles = {
         'beamtimeid.ds.xml',
         'start_time.ds.xml',
     ],
+    'starttime': [
+        'starttime.xml',
+        'starttime.ds.xml',
+        'start_timestamp.ds.xml',
+        'client_start_time.ds.xml',
+    ],
     'beamtimefname': [
         'beamtimefname.xml',
         'beamtimefname.ds.xml',
