@@ -87,7 +87,7 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
         self._buint = "uint64" if IS64BIT else "uint32"
         self._bfloat = "float64" if IS64BIT else "float32"
 
-        self.__args = '{"host":"localhost", "db":"nxsconfig", ' \
+        self.__args = '{"db":"nxsconfig", ' \
                       '"read_default_file":"/etc/my.cnf", "use_unicode":true}'
 
         # home = expanduser("~")
@@ -303,11 +303,12 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
                      "common2", "common3",
                      "datasignal", "dcm", "default", "defaultinstrument",
                      "defaultsample", "detectorlive",
-                     "empty", "keithley", "maia",
+                     "empty", "groupsecop", "keithley", "maia",
                      "maiadimension", "maiaflux", "msnsar", "mssar",
                      "pinhole",
-                     "pointdet", "qbpm", "samplehkl", "slit",
-                     "source", "undulator"])
+                     "pointdet", "qbpm", "samplehkl", "secop",
+                     "singlesecop", "slit", "source", "starttime",
+                     "undulator"])
                 self.assertEqual(lines[-1], "")
         finally:
             pass
@@ -324,10 +325,11 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
                  "common2", "common3",
                  "datasignal", "dcm", "default", "defaultinstrument",
                  "defaultsample", "detectorlive",
-                 "empty", "keithley", "maia",
+                 "empty", "groupsecop", "keithley", "maia",
                  "maiadimension", "maiaflux", "pinhole",
-                 "pointdet", "qbpm", "samplehkl", "slit",
-                 "source", "undulator"]
+                 "pointdet", "qbpm", "samplehkl",
+                 "secop", "singlesecop", "slit",
+                 "source", "starttime", "undulator"]
         args = [
                 ('nxscreate stdcomp %s -t ' % self.flags).split(),
                 ('nxscreate stdcomp %s --type ' % self.flags).split(),
